==> cr12g-panhuo-impl-3.0.0-20210511.123518-21-sources.jar: com/ejianc/business/asset/bean/CheckDetailEntity.java <==
package com.ejianc.business.asset.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 验收实体明细
 * 
 * @author generator
 * 
 */
 @TableName("ejc_panhuo_check_detail")
public class CheckDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="check_id")
    private java.lang.Long checkId; // 验收主键ID
    @TableField(value="allot_id")
    private java.lang.Long allotId; // 调拨单主键ID
    @TableField(value="material_id")
    private java.lang.Long materialId; // 物资主键
    @TableField(value="material_name")
    private java.lang.String materialName; // 物资名称
    @TableField(value="material_type_id")
    private java.lang.Long materialTypeId; // 物资类别
    @TableField(value="material_type_name")
    private java.lang.String materialTypeName; // 物资类别名称
    @TableField(value="material_code")
    private java.lang.String materialCode; // 物料编码
    @TableField(value="unit")
    private java.lang.String unit; // 单位
    @TableField(value="spec")
    private java.lang.String spec; // 规格型号
    @TableField(value="memo")
    private java.lang.String memo; // 备注
    @TableField(value="material_type_code")
    private java.lang.String materialTypeCode; // 物资类别编号
    @TableField(value="asset_type")
    private java.lang.Integer assetType; // 物资类型 0-周转材，1-台车
    @TableField(value="asset_code")
    private java.lang.String assetCode; // 资产编码
    @TableField(value="asset_id")
    private java.lang.Long assetId; // 资产编码id
    @TableField(value="capacity")
    private java.math.BigDecimal capacity; // 承载量
    @TableField(value="allot_num")
    private java.math.BigDecimal allotNum; // 调拨数量
    @TableField(value="allot_price")
    private java.math.BigDecimal allotPrice; // 调拨单价
    @TableField(value="allot_money")
    private java.math.BigDecimal allotMoney; // 调拨金额
    @TableField(value="check_num")
    private java.math.BigDecimal checkNum; // 验收数量
    @TableField(value="check_price")
    private java.math.BigDecimal checkPrice; // 验收单价
    @TableField(value="check_money")
    private java.math.BigDecimal checkMoney; // 验收金额
    @TableField(value="check_ton")
    private java.lang.String checkTon; // 验收重量
    @TableField(value="belong_type")
    private java.lang.Integer belongType; // 类型 0=项目，1=公司
    @TableField(value="asset_belong_type")
    private java.lang.Integer assetBelongType; // 资产归属类型 0=项目，1=公司
    @TableField(value="belong_org_id")
    private java.lang.Long belongOrgId; // 归属公司id
    @TableField(value="belong_org_name")
    private java.lang.String belongOrgName; // 归属公司name
    
    
    

    /**
     * 验收主键ID
     */
    public java.lang.Long getCheckId() {
        return checkId;
    }

    /**
     * 验收主键ID
     */
    public void setCheckId(java.lang.Long checkId) {
        this.checkId = checkId;
    }
    /**
     * 调拨单主键ID
     */
    public java.lang.Long getAllotId() {
        return allotId;
    }

    /**
     * 调拨单主键ID
     */
    public void setAllotId(java.lang.Long allotId) {
        this.allotId = allotId;
    }
    /**
     * 物资主键
     */
    public java.lang.Long getMaterialId() {
        return materialId;
    }

    /**
     * 物资主键
     */
    public void setMaterialId(java.lang.Long materialId) {
        this.materialId = materialId;
    }
    /**
     * 物资名称
     */
    public java.lang.String getMaterialName() {
        return materialName;
    }

    /**
     * 物资名称
     */
    public void setMaterialName(java.lang.String materialName) {
        this.materialName = materialName;
    }
    /**
     * 物资类别
     */
    public java.lang.Long getMaterialTypeId() {
        return materialTypeId;
    }

    /**
     * 物资类别
     */
    public void setMaterialTypeId(java.lang.Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    /**
     * 物资类别名称
     */
    public java.lang.String getMaterialTypeName() {
        return materialTypeName;
    }

    /**
     * 物资类别名称
     */
    public void setMaterialTypeName(java.lang.String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    /**
     * 物料编码
     */
    public java.lang.String getMaterialCode() {
        return materialCode;
    }

    /**
     * 物料编码
     */
    public void setMaterialCode(java.lang.String materialCode) {
        this.materialCode = materialCode;
    }
    /**
     * 单位
     */
    public java.lang.String getUnit() {
        return unit;
    }

    /**
     * 单位
     */
    public void setUnit(java.lang.String unit) {
        this.unit = unit;
    }
    /**
     * 规格型号
     */
    public java.lang.String getSpec() {
        return spec;
    }

    /**
     * 规格型号
     */
    public void setSpec(java.lang.String spec) {
        this.spec = spec;
    }
    /**
     * 备注
     */
    public java.lang.String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(java.lang.String memo) {
        this.memo = memo;
    }
    /**
     * 物资类别编号
     */
    public java.lang.String getMaterialTypeCode() {
        return materialTypeCode;
    }

    /**
     * 物资类别编号
     */
    public void setMaterialTypeCode(java.lang.String materialTypeCode) {
        this.materialTypeCode = materialTypeCode;
    }
    /**
     * 物资类型 0-周转材，1-台车
     */
    public java.lang.Integer getAssetType() {
        return assetType;
    }

    /**
     * 物资类型 0-周转材，1-台车
     */
    public void setAssetType(java.lang.Integer assetType) {
        this.assetType = assetType;
    }
    /**
     * 资产编码
     */
    public java.lang.String getAssetCode() {
        return assetCode;
    }

    /**
     * 资产编码
     */
    public void setAssetCode(java.lang.String assetCode) {
        this.assetCode = assetCode;
    }
    /**
     * 资产编码id
     */
    public java.lang.Long getAssetId() {
        return assetId;
    }

    /**
     * 资产编码id
     */
    public void setAssetId(java.lang.Long assetId) {
        this.assetId = assetId;
    }
    /**
     * 承载量
     */
    public java.math.BigDecimal getCapacity() {
        return capacity;
    }

    /**
     * 承载量
     */
    public void setCapacity(java.math.BigDecimal capacity) {
        this.capacity = capacity;
    }
    /**
     * 调拨数量
     */
    public java.math.BigDecimal getAllotNum() {
        return allotNum;
    }

    /**
     * 调拨数量
     */
    public void setAllotNum(java.math.BigDecimal allotNum) {
        this.allotNum = allotNum;
    }
    /**
     * 调拨单价
     */
    public java.math.BigDecimal getAllotPrice() {
        return allotPrice;
    }

    /**
     * 调拨单价
     */
    public void setAllotPrice(java.math.BigDecimal allotPrice) {
        this.allotPrice = allotPrice;
    }
    /**
     * 调拨金额
     */
    public java.math.BigDecimal getAllotMoney() {
        return allotMoney;
    }

    /**
     * 调拨金额
     */
    public void setAllotMoney(java.math.BigDecimal allotMoney) {
        this.allotMoney = allotMoney;
    }
    /**
     * 验收数量
     */
    public java.math.BigDecimal getCheckNum() {
        return checkNum;
    }

    /**
     * 验收数量
     */
    public void setCheckNum(java.math.BigDecimal checkNum) {
        this.checkNum = checkNum;
    }
    /**
     * 验收单价
     */
    public java.math.BigDecimal getCheckPrice() {
        return checkPrice;
    }

    /**
     * 验收单价
     */
    public void setCheckPrice(java.math.BigDecimal checkPrice) {
        this.checkPrice = checkPrice;
    }
    /**
     * 验收金额
     */
    public java.math.BigDecimal getCheckMoney() {
        return checkMoney;
    }

    /**
     * 验收金额
     */
    public void setCheckMoney(java.math.BigDecimal checkMoney) {
        this.checkMoney = checkMoney;
    }
    /**
     * 验收重量
     */
    public java.lang.String getCheckTon() {
        return checkTon;
    }

    /**
     * 验收重量
     */
    public void setCheckTon(java.lang.String checkTon) {
        this.checkTon = checkTon;
    }
    /**
     * 类型 0=项目，1=公司
     */
    public java.lang.Integer getBelongType() {
        return belongType;
    }

    /**
     * 类型 0=项目，1=公司
     */
    public void setBelongType(java.lang.Integer belongType) {
        this.belongType = belongType;
    }
    /**
     * 资产归属类型 0=项目，1=公司
     */
    public java.lang.Integer getAssetBelongType() {
        return assetBelongType;
    }

    /**
     * 资产归属类型 0=项目，1=公司
     */
    public void setAssetBelongType(java.lang.Integer assetBelongType) {
        this.assetBelongType = assetBelongType;
    }
    /**
     * 归属公司id
     */
    public java.lang.Long getBelongOrgId() {
        return belongOrgId;
    }

    /**
     * 归属公司id
     */
    public void setBelongOrgId(java.lang.Long belongOrgId) {
        this.belongOrgId = belongOrgId;
    }
    /**
     * 归属公司name
     */
    public java.lang.String getBelongOrgName() {
        return belongOrgName;
    }

    /**
     * 归属公司name
     */
    public void setBelongOrgName(java.lang.String belongOrgName) {
        this.belongOrgName = belongOrgName;
    }
    
}

==> cr12g-panhuo-impl-3.0.0-20210518.074106-51-sources.jar: com/ejianc/business/asset/bean/CheckDetailEntity.java <==
package com.ejianc.business.asset.bean;

import java.math.BigDecimal;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 验收实体明细
 * 
 * @author generator
 * 
 */
 @TableName("ejc_panhuo_check_detail")
public class CheckDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="check_id")
    private java.lang.Long checkId; // 验收主键ID
    @TableField(value="allot_id")
    private java.lang.Long allotId; // 调拨单主键ID
    @TableField(value="material_id")
    private java.lang.Long materialId; // 物资主键
    @TableField(value="material_name")
    private java.lang.String materialName; // 物资名称
    @TableField(value="material_type_id")
    private java.lang.Long materialTypeId; // 物资类别
    @TableField(value="material_type_name")
    private java.lang.String materialTypeName; // 物资类别名称
    @TableField(value="material_code")
    private java.lang.String materialCode; // 物料编码
    @TableField(value="unit")
    private java.lang.String unit; // 单位
    @TableField(value="spec")
    private java.lang.String spec; // 规格型号
    @TableField(value="memo")
    private java.lang.String memo; // 备注
    @TableField(value="material_type_code")
    private java.lang.String materialTypeCode; // 物资类别编号
    @TableField(value="asset_type")
    private java.lang.Integer assetType; // 物资类型 0-周转材，1-台车
    @TableField(value="asset_code")
    private java.lang.String assetCode; // 资产编码
    @TableField(value="asset_id")
    private java.lang.Long assetId; // 资产编码id
    @TableField(value="capacity")
    private java.math.BigDecimal capacity; // 承载量
    @TableField(value="allot_num")
    private java.math.BigDecimal allotNum; // 调拨数量
    @TableField(value="allot_price")
    private java.math.BigDecimal allotPrice; // 调拨单价
    @TableField(value="allot_money")
    private java.math.BigDecimal allotMoney; // 调拨金额
    @TableField(value="check_num")
    private java.math.BigDecimal checkNum; // 验收数量
    @TableField(value="check_price")
    private java.math.BigDecimal checkPrice; // 验收单价
    @TableField(value="check_money")
    private java.math.BigDecimal checkMoney; // 验收金额
    @TableField(value="check_ton")
    private java.math.BigDecimal checkTon; // 验收重量
    @TableField(value="asset_belong_type")
    private java.lang.Integer assetBelongType; // 资产归属类型 0=项目，1=公司
    @TableField(value="belong_org_id")
    private java.lang.Long belongOrgId; // 归属公司id
    @TableField(value="belong_org_name")
    private java.lang.String belongOrgName; // 归属公司name
    
    
    

    /**
     * 验收主键ID
     */
    public java.lang.Long getCheckId() {
        return checkId;
    }

    /**
     * 验收主键ID
     */
    public void setCheckId(java.lang.Long checkId) {
        this.checkId = checkId;
    }
    /**
     * 调拨单主键ID
     */
    public java.lang.Long getAllotId() {
        return allotId;
    }

    /**
     * 调拨单主键ID
     */
    public void setAllotId(java.lang.Long allotId) {
        this.allotId = allotId;
    }
    /**
     * 物资主键
     */
    public java.lang.Long getMaterialId() {
        return materialId;
    }

    /**
     * 物资主键
     */
    public void setMaterialId(java.lang.Long materialId) {
        this.materialId = materialId;
    }
    /**
     * 物资名称
     */
    public java.lang.String getMaterialName() {
        return materialName;
    }

    /**
     * 物资名称
     */
    public void setMaterialName(java.lang.String materialName) {
        this.materialName = materialName;
    }
    /**
     * 物资类别
     */
    public java.lang.Long getMaterialTypeId() {
        return materialTypeId;
    }

    /**
     * 物资类别
     */
    public void setMaterialTypeId(java.lang.Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    /**
     * 物资类别名称
     */
    public java.lang.String getMaterialTypeName() {
        return materialTypeName;
    }

    /**
     * 物资类别名称
     */
    public void setMaterialTypeName(java.lang.String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    /**
     * 物料编码
     */
    public java.lang.String getMaterialCode() {
        return materialCode;
    }

    /**
     * 物料编码
     */
    public void setMaterialCode(java.lang.String materialCode) {
        this.materialCode = materialCode;
    }
    /**
     * 单位
     */
    public java.lang.String getUnit() {
        return unit;
    }

    /**
     * 单位
     */
    public void setUnit(java.lang.String unit) {
        this.unit = unit;
    }
    /**
     * 规格型号
     */
    public java.lang.String getSpec() {
        return spec;
    }

    /**
     * 规格型号
     */
    public void setSpec(java.lang.String spec) {
        this.spec = spec;
    }
    /**
     * 备注
     */
    public java.lang.String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(java.lang.String memo) {
        this.memo = memo;
    }
    /**
     * 物资类别编号
     */
    public java.lang.String getMaterialTypeCode() {
        return materialTypeCode;
    }

    /**
     * 物资类别编号
     */
    public void setMaterialTypeCode(java.lang.String materialTypeCode) {
        this.materialTypeCode = materialTypeCode;
    }
    /**
     * 物资类型 0-周转材，1-台车
     */
    public java.lang.Integer getAssetType() {
        return assetType;
    }

    /**
     * 物资类型 0-周转材，1-台车
     */
    public void setAssetType(java.lang.Integer assetType) {
        this.assetType = assetType;
    }
    /**
     * 资产编码
     */
    public java.lang.String getAssetCode() {
        return assetCode;
    }

    /**
     * 资产编码
     */
    public void setAssetCode(java.lang.String assetCode) {
        this.assetCode = assetCode;
    }
    /**
     * 资产编码id
     */
    public java.lang.Long getAssetId() {
        return assetId;
    }

    /**
     * 资产编码id
     */
    public void setAssetId(java.lang.Long assetId) {
        this.assetId = assetId;
    }
    /**
     * 承载量
     */
    public java.math.BigDecimal getCapacity() {
        return capacity;
    }

    /**
     * 承载量
     */
    public void setCapacity(java.math.BigDecimal capacity) {
        this.capacity = capacity;
    }
    /**
     * 调拨数量
     */
    public java.math.BigDecimal getAllotNum() {
        return allotNum;
    }

    /**
     * 调拨数量
     */
    public void setAllotNum(java.math.BigDecimal allotNum) {
        this.allotNum = allotNum;
    }
    /**
     * 调拨单价
     */
    public java.math.BigDecimal getAllotPrice() {
        return allotPrice;
    }

    /**
     * 调拨单价
     */
    public void setAllotPrice(java.math.BigDecimal allotPrice) {
        this.allotPrice = allotPrice;
    }
    /**
     * 调拨金额
     */
    public java.math.BigDecimal getAllotMoney() {
        return allotMoney;
    }

    /**
     * 调拨金额
     */
    public void setAllotMoney(java.math.BigDecimal allotMoney) {
        this.allotMoney = allotMoney;
    }
    /**
     * 验收数量
     */
    public java.math.BigDecimal getCheckNum() {
        return checkNum;
    }

    /**
     * 验收数量
     */
    public void setCheckNum(java.math.BigDecimal checkNum) {
        this.checkNum = checkNum;
    }
    /**
     * 验收单价
     */
    public java.math.BigDecimal getCheckPrice() {
        return checkPrice;
    }

    /**
     * 验收单价
     */
    public void setCheckPrice(java.math.BigDecimal checkPrice) {
        this.checkPrice = checkPrice;
    }
    /**
     * 验收金额
     */
    public java.math.BigDecimal getCheckMoney() {
        return checkMoney;
    }

    /**
     * 验收金额
     */
    public void setCheckMoney(java.math.BigDecimal checkMoney) {
        this.checkMoney = checkMoney;
    }

    public BigDecimal getCheckTon() {
        return checkTon;
    }

    public void setCheckTon(BigDecimal checkTon) {
        this.checkTon = checkTon;
    }

    /**
     * 资产归属类型 0=项目，1=公司
     */
    public java.lang.Integer getAssetBelongType() {
        return assetBelongType;
    }

    /**
     * 资产归属类型 0=项目，1=公司
     */
    public void setAssetBelongType(java.lang.Integer assetBelongType) {
        this.assetBelongType = assetBelongType;
    }
    /**
     * 归属公司id
     */
    public java.lang.Long getBelongOrgId() {
        return belongOrgId;
    }

    /**
     * 归属公司id
     */
    public void setBelongOrgId(java.lang.Long belongOrgId) {
        this.belongOrgId = belongOrgId;
    }
    /**
     * 归属公司name
     */
    public java.lang.String getBelongOrgName() {
        return belongOrgName;
    }

    /**
     * 归属公司name
     */
    public void setBelongOrgName(java.lang.String belongOrgName) {
        this.belongOrgName = belongOrgName;
    }
    
}
